pub struct TreeCursor { /* private fields */ }Expand description
A cursor for traversing a Tree.
Implementations
Sourceimpl TreeCursor
impl TreeCursor
Sourcepub fn goto_first_child(&mut self) -> bool
pub fn goto_first_child(&mut self) -> bool
Move the cursor to the first child of the current node.
Returns true if a child existed.
Sourcepub fn goto_parent(&mut self) -> bool
pub fn goto_parent(&mut self) -> bool
Move the cursor to the parent of the current node.
Returns true if a parent existed.
Sourcepub fn goto_next_sibling(&mut self) -> bool
pub fn goto_next_sibling(&mut self) -> bool
Move the cursor to the next sibling of the current node.
Returns true if a sibling existed.
Sourcepub fn field_name(&self) -> Option<String>
pub fn field_name(&self) -> Option<String>
Return the field name for the current node, if any.