pub struct MatchResult {
pub pattern_index: usize,
pub captures: Vec<CaptureResult>,
}Expand description
A single query match containing one or more captures.
Fields
pattern_index: usizeThe pattern index within the query that produced this match.
captures: Vec<CaptureResult>The captures for this match.